package com.srs.android.widgets;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.util.Log;
import android.view.View;
import android.widget.ImageView;


/**
 * This class provides a view which consumes all available space in the parent and then centers its images and provides a background behind the image.
 * Since I am unable to programmatically get the droid layout manager to cooperate, it was ultimately easier to roll a special case ImageView that has
 * more quantifiable behavior.
 * 
 * @author k001694
 *
 */
public class CenteredImageView extends ImageView  {
	
	int resourceIDForImage;
	Bitmap viewImage;
	boolean consumeParentWidth;
	boolean consumeParentHeight;
	boolean centerHorizontal;
	boolean centerVertical;
	
	public CenteredImageView(Context context) {
		super(context);
	}

	
	/**
	 * assign the resource id to use as an image.
	 */
	public void setImageResource(int id) {
		super.setImageResource(id);
		resourceIDForImage = id;
		viewImage = BitmapFactory.decodeResource(getResources(),id);
	}
	
	
	public boolean isConsumeParentWidth() {
		return consumeParentWidth;
	}


	/**
	 * Set this view to consume all the available space in its parent, or not.
	 * If set to false the size of this view's width is the size of the underlying image's width
	 * 
	 * This method also sets the centerHorizontal setting, which can be overridden
	 * but subsequenet calls to setCenterHorizontal if desired.
	 * 
	 * @param consumeParentWidth
	 */
	public void setConsumeParentWidth(boolean consumeParentWidth) {
		this.consumeParentWidth = consumeParentWidth;
		this.centerHorizontal = consumeParentWidth;
	}


	public boolean isConsumeParentHeight() {
		return consumeParentHeight;
	}


	/**
	 * Set this view to consume all the available space in its parent, or not.
	 * If set to false the size of this view's height is the size of the underlying image's height
	 * 
	 * This method also sets the centerVertical setting, which can be overridden
	 * but subsequenet calls to setCenterVertical if desired.
	 * 
	 * @param consumeParentWidth
	 */
	public void setConsumeParentHeight(boolean consumeParentHeight) {
		this.consumeParentHeight = consumeParentHeight;
		this.centerVertical = consumeParentHeight;
	}

	

	public boolean isCenterHorizontal() {
		return centerHorizontal;
	}


	public void setCenterHorizontal(boolean centerHorizontal) {
		this.centerHorizontal = centerHorizontal;
	}


	public boolean isCenterVertical() {
		return centerVertical;
	}


	public void setCenterVertical(boolean centerVertical) {
		this.centerVertical = centerVertical;
	}


	/**
	 * 
	 * Implementation of onMeasure for this custom widget.   Minimually the x,y is defined by the size of
	 * the underlying image,  however all of the parents x,y space is consumed for the axis requeted.
	 * 
	 * Notes:  For some reason can't get this to auto happen with the default onMeasure, so
	 * had to roll my own.  Not a problem, however very curious none the less.
	 * 
	 */
	protected void  onMeasure  (int widthMeasureSpec, int heightMeasureSpec) {

		
		int parentWidth = View.MeasureSpec.getSize(widthMeasureSpec);
		int parentHeight= View.MeasureSpec.getSize(heightMeasureSpec);
		//Log.d("CenterImageView","onmeasure provided dimentions are " + parentWidth + "," + parentHeight);
		int computedWidth = viewImage.getWidth();
		int computedHeight = viewImage.getHeight();
	
		// adjust size consumed based on current view settings
		if(consumeParentWidth)
			computedWidth = parentWidth;
		
		if(consumeParentHeight)
			computedHeight = parentHeight;
		
		setMeasuredDimension(computedWidth,computedHeight);
	}
	
	/**
	 * 
	 *  Implementaon of onDraw for this custom widget.
	 *  
	 */
	protected void onDraw(Canvas can) {

		Paint pt = new Paint();
		pt.setColor(0xFFe3e2a6);
		can.drawRect((float) 0.0,(float) 0.0,(float) getWidth(),(float) getHeight(),pt);
		

		int borderLeft=0;
		int borderTop=0;
		
		if(centerHorizontal) {
			int leftoverborder = getWidth() - this.viewImage.getWidth();
			if(leftoverborder > 0)
				borderLeft = leftoverborder / 2;
			else
				borderLeft = 0;
		}
		
		if(centerVertical) {
			int leftoverborder = getHeight() - this.viewImage.getHeight();
			if(leftoverborder > 0)
				borderTop = leftoverborder / 2;
			else
				borderTop = 0;
		}
		can.drawBitmap(viewImage,borderLeft,borderTop,null);
	}
	
}
